# Qualitative Mathematical Modelling (QMM) in Python

[![Status](https://img.shields.io/badge/Status-Active%20Development-yellow)]()
[![Python Version](https://img.shields.io/badge/Python-3.9%2B-blue)](https://www.python.org/)

Qualitative Mathematical Modelling (QMM) is a method for analysing the structure of complex systems where general causal relationships are known but precise quantitative data are lacking. By utilising signed digraphs (directed graphs) to visualise system structure, QMM enables users to build models of real-world systems and generate testable predictions of system response to perturbations.

## Features

- Python package (`qmm`) for qualitative mathematical modelling, including core modules for defining model structure, stability analysis, perturbation analysis and making qualitative predictions.
- Integration with an interactive web application for creating signed digraph (network) models representing the mathematical structure of a complex system.

!!! tip "Digraph Builder"
    **[Create a model with the Digraph Builder application](https://www.digraphbuilder.com/)**  
    An interactive web app for creating and editing signed digraphs.

## Documentation

- [Getting Started](getting-started.md)
- [Reference](reference.md)

## Contact

Jayden Hyman - <j.hyman@uq.edu.au>
